package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$"`0`````````````"`!0````!`8`2\````#0``0.X```````T`"``
M"``H`"``'P````8````T`8``-`&``#0```$````!``````0````$`````P``
M`30!@`$T`8`!-````!<````7````!`````$````!``````&````!@`````"6
M[```ENP````%``$```````$``/Z$`8'^A`&!_H0```*4```$$`````8``0``
M`````@``_Q`!@?\0`8'_$````.````#@````!@````0````$```!3`&``4P!
M@`%,````+````"P````$````!&1TY5```(X,`8".#`&`C@P```$,```!#```
M``0````$9'3E4@``_H0!@?Z$`8'^A````7P```%\````!`````$O=7-R+VQI
M8F5X96,O;&0N96QF7W-O```````'````!`````%.971"4T0``#6DZ0`````$
M````!`````-085@``````````&$```!D``````````````!#````&P``````
M````````"0```$\````#`````````$0`````````/@```!````!*````````
M`#8````&````%P```$D```!2````#````$T`````````'``````````6````
M7````$$``````````````#$```!B````8P````````!'````3@```$8```!;
M````'@`````````+````0````$4````U````(0```%D``````````````#<`
M````````+0````````!:````)````"@```!@````!P```%X`````````5P``
M``````!6````-````"X```````````````````!1````*P`````````F````
M7P```#D`````````/0`````````Z````80````````!3````&@```!4`````
M````5`````````````````````````!"`````````%@````P````.```````
M``!=``````````````````````````````````````````$`````````````
M``````````````````````````````````````````````````4`````````
M``````T````````````````````````````````````````````````````1
M```````````````````````````````3`````````",`````````%`````0`
M````````````````````````*0`````````/`````````!@````J````)0``
M```````L````````````````````"@```!D`````````````````````````
M)P`````````R`````````#,````B```````````````_````'0```!(`````
M````````````````````"```````````````2````%````!,````````````
M````````(``````````"````.P```$L````\````50`````````.````'P``
M`"\````````````````````````#/@&`130```)L$@``"@```A@`````````
M`!(```````&Z```````````2````````J@&"`2@````!$0``&P```:P`````
M`````!(```````!?```````````2````````#```````````$@```````(\`
M`````````!(```````%M```````````2```````#0P&`)J0````X$@``"@``
M`?```````````!(```````"``8!,\``````2```+```!WP``````````$@``
M`````7D``````````!(```````(H```````````2```````!]P``````````
M$@```````DX``````````!(```````+,`8(!$`````01```9```"JP``````
M````$@```````0```````````!(```````'"```````````2````````90``
M````````$@```````UX!@!X0````$!(```H```"&```````````2```````!
M$P``````````$@```````!0``````````!(````````P```````````2````
M```"UP&"`1@````$$0``&@```#@``````````!(```````'4```````````2
M```````#;P&`)MP```$8$@``"@```.,``````````!(```````.!`8`G]```
M!M`2```*```$`0&`$L@`````$@``"0```KH``````````!(```````(N````
M```````2```````"Y```````````$@```````"(``````````!(```````'^
M```````````2```````#C@&`'=@````X$@``"@```,4``````````!8`````
M``#8```````````2```````!+```````````$@```````Y8!@!+P````'!(`
M``H````I```````````2```````";0``````````(@```````+<`````````
M`!(```````.>`8`CF````(P2```*```#K`&`+L0```)H$@``"@```\(!@$"@
M```!E!(```H```%/`8'^F````!,1```2```"\0``````````$@```````\T!
M@@$4````!!$``!D```"<```````````2```````#EP&`$O`````<$@``"@``
M`DD!@@$P```!"!$``!L```#L`8(!(`````01```:```#UP&`(/0```!`$@``
M"@```1H!@@(X````(!$``!L```%>```````````2```````"^P``````````
M$@```````)```````````!(```````'_```````````2```````"A0``````
M````(@```````A\``````````!(```````/D`8(!&``````0```:```#\`&"
M`I0`````$```&P```0<``````````!(```````%*```````````2````````
M4```````````$@```````_8!@"0D````G!(```H````<```````````2````
M````0`&`2H``````$@```````_X!@$`P````<!(```H```('`8!*D``````2
M```````$!P&`(30```!X$@``"@```<X``````````!(```````03`8`AK```
M`>P2```*```#"```````````$@```````3P``````````!(```````![````
M```````2```````$(`&"`1@`````$```&0``!"<!@!X@```"U!(```H```&9
M`8!*X``````2```````$-`&`0C0```&@$@``"@```&P``````````!(`````
M``,/```````````2```````!C@``````````$@```````QH``````````!(`
M``````,A```````````2```````",P``````````$@```````_$!@@*4````
M`!```!L```"5```````````2````````=@``````````$@```````D(`````
M`````!(```````,M```````````2```````$/@&`,2P```"4$@``"@```CL`
M`````````!(```````#T```````````2`````&QI8G!E<FPN<V\`<F5A;&QO
M8P!M96UM;W9E`')M9&ER`'-T<G-T<@!S=')C:'(`<W1R;F-M<`!S=')R8VAR
M`&)O;W1?1'EN84QO861E<@!P97)L7V-O;G-T<G5C=`!A8F]R=`!U;FQI;FL`
M7U]L<W1A=#4P`'!E<FQ?9G)E90!?9FEN:0!?7W-T870U,`!?97AI=`!M96UC
M<'D`<&5R;%]D97-T<G5C=`!03%]D;U]U;F1U;7``4&5R;%]S=E]S971P=@!0
M3%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E;G9I<F]N
M`%]?;W!E;F1I<C,P`&UE;7-E=`!097)L7W-A9F5S>7-M86QL;V,`7U]S=&%C
M:U]C:&M?9W5A<F0`4&5R;%]G=E]F971C:'!V`%]?<W!R:6YT9E]C:&L`<F5A
M9`!03%]M96UO<GE?=W)A<`!097)L7W-Y<U]I;FET,P!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`4&5R;%]M9U]S970`;6MD:7(`
M<&5R;%]P87)S90!097)L7VYE=UA37V9L86=S`&%C8V5S<P!G971P:60`=F9P
M<FEN=&8`4&5R;%]A=&9O<FM?;&]C:P!M96UC;7``<&5R;%]R=6X`;'-E96L`
M;W!E;@!S<')I;G1F`&=E='5I9`!S=')L96X`7U]S1@!S=')C;7``;&EB;2YS
M;RXP`&QI8F-R>7!T+G-O+C$`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`7U]R
M96=I<W1E<E]F<F%M95]I;F9O`&QI8G!T:')E860N<V\N,0!P=&AR96%D7V%T
M9F]R:P!S=')D=7``;&EB8RYS;RXQ,@!?7W!R;V=N86UE`%]?<'-?<W1R:6YG
M<P!?7V=E='!W=6ED-3``7U]S>7-C86QL`%]?<W1P8W!Y7V-H:P!A=&5X:70`
M7VQI8F-?:6YI=`!S=')T;VL`7U]R96%D9&ER,S``7U]S=&%C:U]C:&M?9F%I
M;`!M86EN`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT
M7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`
M7U]S=&%R=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!S
M:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`
M7U]E;F0`<&%R7V1I90!S:&%?:6YI=`!P87)?9&ER;F%M90!P87)?:6YI=%]E
M;G8`7V5D871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`<&%R7V-L96%N=7``
M+W5S<B]P:V<O;&EB+W!E<FPU+S4N,S@N,"]P;W=E<G!C+6YE=&)S9"UT:')E
M860M;75L=&DO0T]213HO=7-R+W!K9R]L:6(````!@?[X``!``0`````!@?\,
M```N`0`````!@?_P```I20`````!@?Z8```S$P`````!@@$H```$$P`````!
M@@$P```X$P`````!@@(X```[$P`````!@@`````"%0`````!@@`$```#%0``
M```!@@`(```%%0`````!@@`,```&%0`````!@@`0```'%0`````!@@`4```(
M%0`````!@@`8```)%0`````!@@`<```+%0`````!@@`@```-%0`````!@@`D
M```.%0`````!@@`H```/%0`````!@@`L```0%0`````!@@`P```1%0`````!
M@@`T```3%0`````!@@`X```4%0`````!@@`\```5%0`````!@@!````6%0``
M```!@@!$```8%0`````!@@!(```9%0`````!@@!,```:%0`````!@@!0```;
M%0`````!@@!4```=%0`````!@@!8```>%0`````!@@!<```@%0`````!@@!@
M```C%0`````!@@!D```D%0`````!@@!H```E%0`````!@@!L```F%0`````!
M@@!P```G%0`````!@@!T```J%0`````!@@!X```K%0`````!@@!\```M%0``
M```!@@"````N%0`````!@@"$```O%0`````!@@"(```T%0`````!@@",```V
M%0`````!@@"0```\%0`````!@@"4```]%0`````!@@"8```^%0`````!@@"<
M```_%0`````!@@"@``!`%0`````!@@"D``!!%0`````!@@"H``!$%0`````!
M@@"L``!%%0`````!@@"P``!&%0`````!@@"T``!(%0`````!@@"X``!)%0``
M```!@@"\``!+%0`````!@@#```!-%0`````!@@#$``!/%0`````!@@#(``!0
M%0`````!@@#,``!1%0`````!@@#0``!4%0`````!@@#4``!6%0`````!@@#8
M``!7%0`````!@@#<``!8%0`````!@@#@``!9%0`````!@@#D``!:%0`````!
M@@#H``!;%0`````!@@#L``!=%0`````!@@#P``!>%0`````!@@#T``!?%0``
M```!@@#X``!@%0`````!@@#\``!B%0`````!@@$```!C%0````!\"`*FD`$`
M!)0A__!(`#')."$`$(`!``1\"`.F3H``(```````````0I\`!7UH`J8]JP`"
M.:UN''SC.WA]!$-X2``!#90A_^!\"`*F0I\`!9/!`!A_R`*F/]X``I.A`!0[
MWFN8D^$`'(.^@`2#_H``D`$`)'^?Z$!`G``<@3\``#O_``1]*0.F3H`$(7^?
MZ$!!G/_L@`$`)(.A`!2#P0`8?`@#IH/A`!PX(0`@3H``()0A_^!\"`*F0I\`
M!9/!`!A_R`*F/]X``I.!`!`[WFLLD^$`'(.>@`R#_H`(D`$`)'^?X$!`G`!(
MB3\`!Y.A`!0OB0#X0;X`%$@``%")/P`'+XD`^$">`$2!/P`(._\`#(.___1]
M*0.F3H`$(7^?X$"0?0``09S_V(.A`!2``0`D@X$`$(/!`!A\"`.F@^$`'#@A
M`"!.@``@2``SP90A_^!\"`*F0I\`!9.!`!!\G"-YD\$`&'_(`J8_W@`"D`$`
M)#O>:I"380`,DZ$`%)/A`!Q!@@$`@3P``(#^@!R!20``@WZ`("^*``"!'``(
MDX<``)$;``!!G@#,@1Z`))%(``"!20``B2H``"^)``!!G@`@*XD`+SE*``%`
MGO_LD4@``(DJ```OB0``0)[_Z"^#``!!G@`(2``V!4@`-E&!/H`L+XD``$&>
M`+"#_H`0@[Z`,'^?Z$!`G``<@3\``#O_``1]*0.F3H`$(7^?Z$!!G/_L@'Z`
M-$@`-<6#_H`4@[Z`.'^?Z$!`G``<@3\``#O_``1]*0.F3H`$(7^?Z$!!G/_L
M@'Z`/$@`-95+__VI@+L``("<``"`?``$2``P!4@`-,V!/H`D@5Z`*)%)``!+
M__]@@-Z`&#C@`!,XH``".&```#B```1,QC&"2``T83A@``%(`#*)2__^#4O_
M_U`L`P``E"'_T)/A`"Q!@@$(/2`!@I-A`!R#:0$@+YL``$&>`/R3P0`HB2,`
M`"^)``!!G@#<*XD`/3O```!`G@",@_L``"^?``!!G@"X?`@"II-!`!B0`0`T
M?)HC>).!`"!\?!MXDZ$`)']]VWA_Q?-X?X3C>'_C^WA(`#+U+X,``$">`!!]
M/_"N+XD`/4&>`%R'_0`$+Y\``$">_]2``0`T@T$`&(-A`!Q\"`.F@X$`((.A
M`"2#P0`H?^/[>(/A`"PX(0`P3H``('Q^&WB-/@`!+HD``"N)`#U!E@`(0+[_
M\'_#\%!+__]<?[OH4#O>``%_O19P?__R%).Z``!+__^@@V$`'(/!`"A+__^P
M.\```$O__S`[X```2___H#O@``"#80`<2___E)0A_]!\"`*FDZ$`)#^@`8([
MO0(XD`$`-)/!`"B!/0``D2$`'#D@``"3X0`L/\`!@GQ_&W@X@0`8?^/[>$S&
M,8)+__Z9+X,``$&>`$R!00`8@1X!(%5*$#I]*%(4@.D`!"^'``!\Z%$N0;[_
MS(%)``@OB@``E4D`!$">__0X@0`8?^/[>$S&,8)+__Y1+X,``$">_[R!(0`<
M@5T``'TI4GDY0```0((`((`!`#2#H0`D@\$`*'P(`Z:#X0`L."$`,$Z``"!(
M`#0AE"'_,).A`,1\?1MYD^$`S#_@`8([_P(X@3\``)$A`*PY(```08(`$(D]
M```OB0``0)X`*($A`*R!7P``?2E2>3E```!`@@%0@Z$`Q(/A`,PX(0#03H``
M('P(`J:3@0#`D`$`U$@`,]E\?!MY08(`X),A`+0_(`&`DT$`N#]``8"380"\
M/V`!@)/!`,@[>TUH.UI-;#LY37!_@^-X2``S,2P#``!!@@"X.\,`#7]DVWA_
MP_-X2``P22^#``!!OO_<?T33>'_#\WA(`#`U+X,``$&>_\A_H^MXDP$`L$@`
M,S%\>!MX?\/S>$@`,R5\>!H4.&,``D@`,&E_QO-X?'@;>'^EZWA_),MX3,8Q
M@D@`,M$X@0`0?P/#>$@`,#4O@___?P/#>$&>`!2!(0`852D$)B^)0`!!G@!8
M2``P!7\#PWA(`#(M@P$`L$O__U"``0#4@X$`P'P(`Z9+__[<?X/C>$@`,$U_
MH^MX2``QI8`!`-2#(0"T@T$`N'P(`Z:#80"\@X$`P(/!`,A+__ZL2__^=4O_
M_ZQ\"`*FDP$`L)`!`-23(0"TDT$`N)-A`+R3@0#`D\$`R$@`,FF4(?_@?`@"
MICS``8`\H`&`D^$`'#_@`8([___TD`$`)(/___P\@`&`?_\2%#C&322`?P``
M.*5*@#B$37A(`#&Y@`$`)#S@`8"`?P``..=09#R@`8`\@`&`@^$`''SF.W@X
MI2[$.(1-E#D```!\"`.F."$`($@`+I"4(?^P?`@"II`!`%2380`\DX$`0'Q\
M&WB3H0!$D\$`2#_``8*3X0!,.]X".),A`#2!7@``D4$`'#E```"300`XB20`
M`&DI`#TA*0``?^0!E'_C^WA(`#&).($`&'Q[&WA_@^-X3,8Q@DO_^WE\?1MY
M08(!)$@`,6E_@]A`0)P`_(,A`!@_0`&"5SD0.HD\```OB0``09X!P"N)`#U!
MG@&X?X/C>$@```PKB0`]09X`$(TC``$OB0``0)[_\'Q\&%`[>P`"@[H!('Q[
M&A1(`"YA+X,``'Q]R2Y!G@&8B3P``(%!`!B!&@$@+XD``%5*$#I]2%`NF2H`
M`$"^`!A(```<C3P``2^)``"=*@`!09X`#"N)`#U`GO_L.2``/3O___^9*@``
MC3\``2^)``"=*@`!0)[_]#A@``"!(0`<@5X``'TI4GDY0```0((!,(`!`%2#
M(0`T@T$`.'P(`Z:#80`\@X$`0(.A`$2#P0!(@^$`3#@A`%!.@``@.____SN]
M__^-/P`!+XD``)T]``%`GO_T2___I#]``8*3`0`PDN$`+(,:`2"!.```+XD`
M`$&>`+!_",-X.4```$@```A_JNMXA2@`!#NJ``$OB0``0)[_\#E*``-51!`Z
M/4`!@H$J`H0OB0``0)X`4#D@``%\@R-XD2H"A$@`+3E\=QMY08(`;%>Y$#I_
M!,-X?R7+>$@`+3&2^@$@.3T``3E```!5*1`Z?5=)+I.A`!B"X0`L@P$`,$O_
M_EQ_`\-X2``L%2^#``!\=QMXD'H!($&>`"!7N1`Z2___Q#A@``!+__YH.(``
M"#N@``!+__]T@N$`+(,!`#`X8/__2__^Q)+A`"R3`0`P2``O;90A_T!\"`*F
MD\$`N#B!`!"3X0"\/^`!@I`!`,0[_P(X?'X;>($_``"1(0"L.2```$@`+JDL
M`P``0((`9($A`!A5*00F*XE``$&>`#QM*O__+XJ@`$&>`#"!(0"L@5\``'TI
M4GDY0```0((`/(`!`,2#P0"X@^$`O'P(`Z8X(0#`3H``('_#\W@X@``"2``K
M;7QC`#148]E^2___P#A@``!+__^X2``NQ90A^]!\"`*F?&0;>#B@!`"3P00H
M/\`!@I/A!"P[X0`<.]X".'_C^WB!/@``D2$$'#D@``"0`00T2``L^7T_&%`Y
M*?__?5]*%'^*^$!`G0`X?3](KB^)`"]`G@`L.2$`'3E```!]*1A0?2D#ID@`
M`!")(___+XD`+T">``R=0___0@#_\#B``"]_X_MX2``KI2P#``!!@@!,?X/X
M0$&=`#A_X_MX2``KO8$A!!R!7@``?2E2>3E```!`@@!<@`$$-(/!!"B#X00L
M?`@#IC@A!#!.@``@.4```)E#``!+___$@2$$'(%>``!]*5)Y.4```$""`"2`
M`00T/&`!@(/!!"@X8TUH@^$$+'P(`Z8X(00P2``K4$@`+:T](`&"E"'_\#DI
M__0\P`&`@2G__#R@`8!]*1(4/(`!@(!I```XQDTD.*5*@#B$37@X(0`02``M
M!)0A__`X8```."$`$$Z``""4(?L0?8``)CT@`8!\"`*FDT$$V#]``8*3@03@
M.UH".)/A!.Q\?!MX?)\C>#AI3:PX@0`<D`$$]),A!-2!.@``D2$$O#D@``"1
M@03`3,8Q@DO_]P5\>1MX.(``+W^#XWA(`"L1+X,``$&>`%@\8`&`?X3C>#AC
M3;A,QC&"2__Z^7^#XWB!(02\@5H``'TI4GDY0```0(("((`!!/2!@03`@R$$
MU'P(`Z:#0038?8"!((.!!."#X03L."$$\$Z``""3803</V`!@'_C^W@[>TW(
M2``J,7]DVWA(`"PI?'\;>4&"`<R2H03$+AD``)+!!,@ZH```DN$$S#[``8"3
M`030/N`!@#\``8"3P03HDZ$$Y#K636@Z]U"8.QA-S&*U@``[H```B3\``"^)
M``!!G@$,09(`&'_D^WA_(\MX2``I!2^#``!!G@#`?^/[>$@`+`4Y0___?'X;
M>'T_4A1_GTA`0)P`1'T_4*XOB0`O0)X`.'Q_&A0Y7P`!?2H84'TI`Z9(```0
MB4/__R^*`"]`G@`,GZ/__T(`__!_X_MX2``KM7Q^&WA_@^-X2``KJ7QC\A0[
MPP`!*YX#_T&=`&!_Y_MX?XGC>'[HNWA_!L-X.*`$`#B````X80"\3,8Q@D@`
M*L4X@0`@.&$`O$@`**DO@P``0)X`%($A`"A5*00F?XFH`$&>`%Q_9-MX.&``
M`$@`*O5\?QMY0(+_$(*A!,2"P03(@N$$S(,!!-"#803<@Z$$Y(/!!.A+__XX
M09(`&'[$LWA_(\MX2``G_2^#``!!GO^X.\```7[?LWA+__],.(```3AA`+Q(
M`">-+X,``$">_Y@\8`&`.($`O#AC3;A,QC&"2__X]3AA`+Q(`"AY@J$$Q(+!
M!,B"X03,@P$$T(-A!-R#H03D@\$$Z$O__=R#803<2__]O)*A!,22P03(DN$$
MS),!!-"3803<DZ$$Y)/!!.A(`"J1E"'_X'P(`J8X@``OD^$`''Q_&WB0`0`D
M2``GY2P#``!!@@`(.^,``8`!`"1_X_MX@^$`'#@A`"!\"`.F2``G\)0A_^"3
MX0`<?'\;>4&"`$")/P``+XD``$&>`#1\"`*FD`$`)$@`*ADX8P`!*X,$`$&=
M`#"``0`D?^/[>(/A`!PX(0`@?`@#IDO_^T0\8`&`@^$`'#AC36@X(0`@2``G
MD(`!`"0X8```@^$`'#@A`"!\"`.F3H``()0A_\!\"`*F/&`!@)`!`$0X8TW4
MDV$`+#]@`8"3@0`P.WM.&).A`#0_H`&`D\$`.#_``8"3X0`\/^`!@CO_`C@[
MWDW\@3\``)$A`!PY(```3,8Q@DO_])T\8`&`.&--X$S&,8)+__2-/&`!@#AC
M3>@[O4VL3,8Q@DO_]'D\8`&`.&--]#^``8!,QC&"2__T97_#\WA,QC&"2__T
M63Q@`8`X8TX,.YQ.)$S&,8)+__1%?Z/K>$S&,8)+__0Y?V/;>$S&,8)+__0M
M?X/C>$S&,8)+__0A/&`!@#AC3C!,QC&"2__T$3Q@`8`X8TVX3,8Q@DO_]`$\
M8`&`.($`&#AC3CQ,QC&"2__RQ7QD&WE!@@`0?X/C>$S&,8)+__;1/&`!@#B!
M`!@X8TY03,8Q@DO_\IU\9!MY08(`%#Q@`8`X8TYD3,8Q@DO_]J4\8`&`.($`
M&#AC3G!,QC&"2__R<7QD&WE!@@!<?Z/K>$S&,8)+__9]/(`!@'_#\W@XA$Z4
M3,8Q@DO_]FF!(0`<@5\``'TI4GDY0```0((`5(`!`$2#80`L@X$`,'P(`Z:#
MH0`T@\$`.(/A`#PX(0!`3H``(#Q@`8`X@0`8.&-.@$S&,8)+__']?&0;>4&B
M_YQ_8]MX3,8Q@DO_]@E+__^,2``G[90A_]!\"`*F/&`!@)/A`"P_X`&"D`$`
M-#O_`C@X8TX8.($`&($_``"1(0`<.2```$S&,8)+__&I+`,``#D@``!!@@`<
MB&,``"^#``!!G@`0:&,`,#$C__]]*1D0@4$`'($?``!]2D)Y.0```'TC2WA`
M@@`8@`$`-(/A`"PX(0`P?`@#IDZ``"!(`"=AE"'_@'P(`J:0`0"$D($`%)"A
M`!B0P0`<D.$`()$!`"21(0`HD4$`+$"&`"38(0`PV$$`.-AA`$#8@0!(V*$`
M4-C!`%C8X0!@V0$`:#U``8(](`&"?&0;>#DI`C@X:@'@.,```3C@```Y`0"(
M.4$`$#BA`'"!:0``D6$`?#E@``"8P0!PF.$`<9$!`'2100!X2``DK3A@`/](
M`"5%/`#__GPL"WA@`/^P/2```7PA`6Y\"`*F82D`'#C@``*3#/_@DTS_Z#\`
M`8*3;/_L.Q@".)/,__@XH```D`P`!#C```"2[/_<?'H;>),L_^23C/_PDZS_
M])/L__R!6```?4D)+CE```!(`",9,23__WQC`=1\>_YP?3[:>'_;\!!7W@0^
M?][:>'_;\!!_>]D0?]Y($'][&1`OFP``09P!$#[@``$_@`&".Z$`%&+W``@[
MG`$$/R#__SC@``!_9=MX?\;S>']#TWA(`"*Y+X/__T&>`/A^Y;MX?Z3K>']#
MTWA(`"2Q+X/__T&>`-`K@P`'0)T`I#AC__A__1H4?Y_H0$"\`!1(``"0.___
M_W^?Z$!!G`"$.*``"'^$XWA_X_MX2``AP2^#``!`GO_@.($`%'R$^%!\@_YP
M?(3P%'QCV10](``!82D`''U)""Z!.```?4I*>3D@``!`@@"(@6$``(`+``2"
MZ__<@PO_X'P(`Z:#*__D@TO_Z(-K_^R#B__P@ZO_](/+__B#Z__\?6%;>$Z`
M`"!_WL@4?WL!U"^;__]`GO\8?Y[(`$">_Q`X8/__.(#__TO__XP\8`&`.&-.
MJ$S&,8)+__VA+X3__T">_P@\8`&`.&-.F$S&,8)+__V)2``DX90A__!\"`*F
MD`$`%$@`).%(`"*-+`,``$&"`!B`8P``@`$`%#@A`!!\"`.F3H``(#A@``!+
M___LE"'_P'P(`J:3P0`X/\`!@).!`#`[WDZTDZ$`-#B!`!B3X0`\/^`!@I`!
M`$1\?1MX._\".'_#\WB!/P``D2$`'#D@``!,QC&"2__N47Q\&WE_I.MX08(`
M?(D\```OB0``09X`<$@`(A$O@P``0+X`<'^CZWB380`L2``D'7Q[&WA_@^-X
M2``D$7Q[&A0X8P`"2``A53S``8`\@`&`?'L;>'^'XWA_I>MX.,9-R#B$3<Q,
MQC&"2``CL7]DVWA_P_-X3,8Q@DO_\?6#80`L2```$'_#\WA,QC&"2__QX8$A
M`!R!7P``?2E2>3E```!`@@`D@`$`1(.!`#"#H0`T?`@#IH/!`#B#X0`\."$`
M0$Z``""380`L2``CD90A_K!\"`*FD\$!2#_``8`[WDTDDX$!0($>`!`_@`&"
M@5X`%#N<`CB!/@`8.($`'(#^`!R1`0`D@1P``)$!`1PY````D4$`*($>`""!
M7@`DD2$`.($^`"B380$\/V`!@(#>``P[>TVLD.$`/)$!`$"`_@`L@1X`,)%!
M`$21(0!(@5X`-($^`#B300$X?'H;>']CVWB0`0%4D^$!3)#!`""0X0!,D0$`
M+)%!`#"1(0`T3,8Q@DO_[,U\?QMY08(`$(D_```OB0``0)X"H).A`422X0$L
MDP$!,),A`31+__W5?'T;>4&"`IA_H^MX2``BD51C"#PX8P`!2``?U8B]``!\
M>1MX+X4``$&>`#`_``&`?S_+>#L83LQ_X_MX?P3#>$S&,8)(`"(IC+T``3O_
M``(OA0``0)[_Y(!A`#@O@P``09X!4#OA`#A(```0A'\`!"^#``!!G@$\.($`
M'$S&,8)+_^PA?'T;>4&B_^2)/0``+XD``$&>_]A+__*M+X,``$&>_\Q_H^MX
M2``?I7Q]&WE!@@$`?Z/K>#[@`8!(`"'A.O=0F'Q_&WA_(\MX2``AT7Q_&A0[
MXP0$?^/[>$@`'Q$\X`&`/(`!@'QX&WA_*,MX?Z7K>'[FNW@XYT[4.(1.W$S&
M,8)(`"%I?P/#>#B``<!(`""]+X/__T&>`2@X@0!0?P/#>$@`(/E\?1MY0((`
M%($A`%A5*00F+XE``$&>`;0\@`&`/&`!@H"Z``!_!L-X.(1/)#AC`>!,QC&"
M2``?X8+A`2P[X```@P$!,(,A`32#H0%$@2$!'(%<``!]*5)Y.4```'_C^WA`
M@@0\@`$!5(-!`3B#80$\?`@#IH.!`4"#P0%(@^$!3#@A`5!.@``@.N```%;I
M$#HY00$@?2I*%(/I_P`OGP``09X`N(D_```OB0``09X`K%;X$#HY(0`@?^/[
M>'\)PA1+__%=.[<``2^#``!_M^MX0)X`-(?X``0OGP``09X`?(D_```OB0``
M09X`<'_C^W@[O0`!2__Q*7^WZW@O@P``09[_U'_C^WA(`!X=?'T;>4&"_WQ+
M__YX2``<G8$C```OB0`109[^T(/Z``!(`!R)@.,``#R``8`\8`&"?^7[>'\&
MPW@XA$[H.&,!X$S&,8)(`![%2__^Y#N@``!+__XP2__[@7_C^WA(`!V]?'\;
M>$O__MP[(```5S\0.CDA`"P[___\?^GZ%(1_``0O@P``09X`;#B!`!P[.0`!
M3,8Q@DO_Z=E\:1MY0:+_X(DI```OB0``09[_U$@`'6U\?1MY0(+]($O__[2#
M(0!L2``?R7^9&`!`GOY$@2$`6)*A`215*07^DL$!*"^)`<!!G@`L@J$!)(+!
M`2A+__X@.&``#3^@`8!(`!S!.[U.Q'QY&W@XH`!32__\\'_C^WA(`!RI.($`
M''Q_&W@\8`&`.&-/>$S&,8)+_^E%?&0;>4&"`6"`>@``2__QX7QY&WE!@@%0
M?R/+>$@`'R$K@P`#?'8;>$"=`#@\@`&`.&/__#B$3X!\>1H42``;\2^#``!`
MG@`<*Y8`!$&>`=A^V;(4B3;_^R^)`"]!G@'(2__W!7QZ&WE`@@`<?R/+>#B`
M``!,QC&"2``<A7QY&WE`@@#L/(`!@#Q@`8`XA$Z4.&-.&#_``8!,QC&"2__L
MQ3O>4&1(`!MY/(`!@'QG&WA_R/-X.(1/K'[FNWA_!<-X?^/[>#]``8!,QC&"
M2``>03M:3[Q(``!`2``:I8$C```OB0`10)X`1$@`&S4[O0`!?&<;>'^HZWA_
MR?-X?N:[>'\%PWA_1--X?^/[>$S&,8)(`!W].(`!P'_C^WA(`!U1+X/__T&>
M_[1_`\-X2``=<7_D^WA_8]MX3,8Q@DO_["5_X_MX2__Y98*A`22"P0$H@N$!
M+(,!`3"#(0$T@Z$!1$O__+2#.@``2__^L$O_]R%\=1MY?)8C>$&@_PPPQ/_V
M..```'RU`=1_(\MX2``:@3B!`.@XH``&?R/+>$@`'($O@P`&0)X`W($A`.B!
M7@`\?XE0`$">_M"A(0#LH5X`0'^)4`!`GO[`,-;_SCC@``!\M0'4?R/+>$@`
M&C5_(\MX.($`\#B@`"A(`!PU+X,`*$">`)`]``&`/(`!@#CA`/!^YKMX.0A0
M9#B$3YQ_!<-X?^/[>)M!`1A,QC&"2``<\4O__PB#6@`$+YH``$&^_C1_0]-X
M2``="2N#``-`O?XD.&/__#R``8!\>AH4.(1/B$@`&=TO@P``0+[^"']9TWA+
M__X`DJ$!))+!`2B2X0$LDP$!,),A`323H0%$2``<T3Q@`8`X8T^03,8Q@DO_
M]664(?_`?`@"ICQ@`8"3X0`\/^`!@CO___23H0`TD`$`1($___R380`L?2D2
M%).!`#`_H`&"D\$`.#N]`CB!70``D4$`'#E````X@0`8@2D``#AC3?R)20!D
MF4D`94S&,8)+_^91+`,``$&"`!")(P``+XD`,4&>`6Q+__)Q@]___#R``8!_
MWA(4.(1/T(!^```XP``#.*```4@`&B5\?!MY08(`,($\``P\H`&`@'X``#BE
M3]2`B0``2``:-8$\``R`B0``@20`"'4I`$!`@@%L@]___#R``8!_WA(4.(1/
MW(!^```XP``#.*```4@`&=%\>QMY08(`,#Q@`8`X@0`8.&--N$S&,8)+_^6I
M?&4;>4&"`02!.P`,@'X``(")``!(`!G-/X`!@CN<`H2#___\/(`!@'__$A0X
MA$_@@]\``#B@``%_P_-X2``7]3R@`8!\9!MX.*5/^'_#\WA(`!F1@3\``#E`
M```\8`&`F4D`93B!`!@X8TVL3,8Q@DO_Y34O@P``D'P`"$&>`&@X@`'`2``:
M32^#`!%!G@`0.2,``2N)``%!G0"@@2$`'(%=``!]*5)Y.4```$""`*R``0!$
M@V$`+(.!`#!\"`.F@Z$`-(/!`#B#X0`\."$`0$Z``"")(P`!+XD``$&^_I1+
M__Z,@'P`!$O_]STO@P``D'P`"$">_XP\8`&`.&-0`$S&,8)(`!==/X`!@H%;
M``P[G`*$@'X``($\``2`B@``@*D``$@`&+U+__[X@'X``$@`%Y%+__Z0@5P`
M!#T@`8"`O``(?&8;>("*```X:5`D3,8Q@D@`%PU(`!I9E"'_X'P(`J:0`0`D
MD\$`&)/A`!Q\?QMX2__O\4O_[ZU\?AMX2__R22^#``!!G@`T+Y\``$&>`"R)
M/P``+XD``$&>`"`\@`&`?\/S>#B$3M0XH``$2``782^#``!!G@`<@`$`)(/!
M`!B#X0`<?`@#IC@A`"!.@``@@`$`)'_C^WB#P0`8@^$`''P(`Z8X(0`@2__E
MJ)0A_H`\@`&".(0".#C@`!"300%H.4$`&)-A`6PY`P`8DX$!<'SI`Z:3H0%T
MD\$!>)/A`7R!)```D2$!7#D@``!]25-XA.@`!)3I``1"`/_X.*$!&'U(4WB$
MZ@`$@2@`.(#(`"1_A5!`@0@`#'TI,GA]*4)X?2DZ>%4I"#Z1*@!`0)[_U($A
M`!R``P`(@,,`##TI6H*!8P`$.2EYF8&#``!\'S)X@*,`$%5]\#Z!00`@59XH
M/G__6#A\".IX/.I:@GTI*A2!00`D?_\R>'TI\A1]"&`X59[P/CCG>9E]*?H4
M?.<R%#_J6H)]"`)X?ZKR>'T(.A1]2D@X@.$`*#O_>9E5/"@^?4KJ>%4I\#Y_
M_P(4?0CB%#]G6H)]2OH4?\=*>(/A`"Q5'"@^?.=`.#M[>9E5"/`^?4KB%'][
MZA1\Y_)X?3U">#^?6H)\Y]H455\H/G^]4#@[G'F9?.?Z%'^<\A2#X0`P?[U*
M>%5*\#Y_O>(45/PH/G^]XA1]'E)X@X$`-#__6H([_WF9?]XX.%3G\#Y]/TH4
M?]Y">'U?.G@_G%J"?]Y*%#N<>9E7J2@^?__H.'_>2A1]'$(4@2$`.'__4GA7
MO?`^?_]"%%?(*#Y__T(4/XE:@H$!`#Q\Z>IX?2GP.#N<>9E7WO`^?YQ2%#T(
M6H)]*CIX?ZGR>%?[*#Y]2N(4.0AYF8.!`$!]*?@X?4K:%%?_\#Y\Z#H4?2GJ
M>'_(^G@_?%J"?2DZ%%5<*#Y]*>(4.WMYF7T(4#B#@0!$54?P/G^[ZA1]"/)X
M?^HZ>'T(ZA0_G%J"53TH/GU*2#A]".H4.YQYF8.A`$A5*?`^?YSR%'U*^GA\
M_DIX/WU:@GU*XA15'2@^?4KJ%'_>0#B#H0!,.WMYF54(\#Y_>_H4?]XZ>'T_
M0G@_G5J"?][:%%5=*#Y__U`X?][J%#N<>9F#H0!054KP/G^<.A1__TIX?0=2
M>#]]6H)__^(45]TH/G__ZA1\Y_`X@Z$`5#M[>9E_>TH4?.E">%?>\#X_G5J"
M?2G:%%?]*#Y]*>H4?4?R>(.A`%A\Y_@X.YQYF5?_\#Y_G$(4?.=2>'_(^G@_
M75J"?0A(.%4]*#Y\Y^(4.UIYF7SGZA2#@0!<?UI2%'T*\GA5*?`^?4K2%%3H
M*#Y__4IX?0I"%#]\6H*!00!@?[TX.#M[>9E4Y_`^?WOR%#^*6H)_OOIX@4$`
M9'T].GA_WMH4?[U`.%4;*#X[G'F950CP/G_>VA1_G/H4/4I:@G^_2GA\_4)X
M5]LH/G__XA0Y2GF9?[WP.(.!`&A7WO`^?__:%'TJ2A1_O3IX?0KR>'^]2A0_
MG%J"5^DH/G^]2A1]2O@X@2$`;#N<>9E_G#H4?4=">%?_\#X]26[:?.?B%%>\
M*#Y\Y^(4@2$`<'_<^G@Y2NNA?YSJ>'U*0A17O?`^/0ENVGU*XA14_"@^?4KB
M%($A`'1__.IX.0CKH7^<.GA]"/(4?0CB%%3^\#Y57"@^/.ENVGT(XA2!(0!X
M?[SR>#CGZZ%_G%)X?.?Z%'SGXA157_`^51PH/CU);MI\Y^(4@2$`?'_<^G@Y
M2NNA?YQ">'U*ZA1]2N(451WP/E3\*#X]"6[:?4KB%($A`(!__.IX.0CKH7^<
M.GA]"/(4?0CB%%3^\#Y57"@^/.ENVGT(XA2!(0"$?[SR>#CGZZ%_G%)X?.?Z
M%'SGXA157_`^51PH/CU);MI\Y^(4@2$`B'_<^G@Y2NNA?YQ">'U*ZA1]2N(4
M51WP/E3\*#X]"6[:?4KB%($A`(Q__.IX.0CKH7^<.GA]"/(4?0CB%%3^\#Y5
M7"@^/.ENVGT(XA2!(0"0?[SR>#CGZZ%_G%)X?.?Z%'SGXA157_`^51PH/CU)
M;MI\Y^(4@2$`E'_<^G@Y2NNA?YQ">'U*ZA1]2N(451WP/E3\*#X]"6[:?4KB
M%($A`)A__.IX.0CKH7^<.GA]"/(4?0CB%%3^\#Y57"@^/.ENVGT(XA2!(0"<
M?[SR>#CGZZ%_G%)X?.?Z%'SGXA157_`^51PH/CU);MI\Y^(4@2$`H'_<^G@Y
M2NNA?YQ">'U*ZA1]2N(451WP/E3\*#X]"6[:?4KB%($A`*1__.IX.0CKH7^<
M.GA]"/(4?0CB%%3^\#Y57"@^/.ENVGT(XA2!(0"H?[SR>#CGZZ%_G%)X?.?Z
M%'SGXA157_`^51PH/CU);MI\Y^(4@2$`K'_<^G@Y2NNA?YQ">'U*ZA1]2N(4
M51WP/E3\*#X]"6[:?4KB%($A`+!__.IX.0CKH7^<.GA]"/(4?0CB%%3^\#Y5
M7"@^/.ENVGT(XA2!(0"T?[SR>#CGZZ%_G%)X?.?Z%'SGXA157_`^51PH/CU)
M;MI\Y^(4@2$`N'_<^G@Y2NNA?4KJ%'^=0GB#@0"\50CP/GU*ZA0]*6[:5/TH
M/G_[0GA]2NH4.2GKH53]\#X_G(\<?V<Z>'TI\A0[G+S<?1[K>'^<^A1]*3H4
M?1_H.%5'*#Y_WE`X?2DZ%'_>^WB`X0#`54KP/E4[*#Y_WN(4?[]3>'_>VA0\
MYX\<@V$`Q'^\4#@XY[S<?_](.'T'0A15*?`^?__C>#^;CQQ]1TMX?_]"%#N<
MO-Q7R"@^?_]"%'^<ZA1\Y_`X?5U(.($!`,A7WO`^?.?K>%?[*#Y]/?-X?.?B
M%#T(CQQ\Y]H4?3SP.(-A`,PY"+S<?[WX.'U(4A1_O>-X5__P/C^;CQQ_O5(4
M5.HH/G^]4A1_R/MX@4$`T#N<O-Q]/$H4?0@X.'_<^#A4Y_`^?0CC>#^*CQP[
MG+S<?^H[>%>[*#Y_G/(4?0A*%'_^.#A7J?`^?4KH.(.A`-1]"-H4?4KS>'S^
M2W@_?8\<?4KB%%4=*#X[>[S<?4KJ%(.A`-A_WD`X?WOZ%'S_2#A5"/`^?]_[
M>#^=CQQ]/D-X55TH/G__VA0[G+S<?__J%'_>4#B#H0#<?YPZ%'TG0#A52O`^
M?\<[>#]]CQQ\Y^(45_TH/GSGZA1]'E-X@Z$`X#M[O-Q_WO@X?WM*%'T)4#A7
M__`^?\E+>#^=CQQ]7OMX5/TH/GTIVA0[G+S<?2GJ%'_>.#B#H0#D?YQ"%'U(
M^#A4Y_`^?\A#>#]]CQQ]".(453TH/GT(ZA1__CMX@Z$`Z#M[O-Q_WD@X?WM2
M%'_J.#A5*?`^?\I3>#^=CQQ\_DMX51TH/GU*VA0[G+S<?4KJ%'^<^A2#H0#L
M?/](.'_>0#A5"/`^?][[>#]]CQQ_WN(455TH/G_>ZA1]/T-X@Z$`\#M[O-Q_
M>SH4?_]0.'TG0#A52O`^?_\[>#^=CQQ]!U-X5]TH/G__VA0[G+S<?__J%'SG
M\#B#H0#T?YQ*%'T)4#A7WO`^?.E+>#]]CQQ]*>(45_TH/GTIZA1]1_-X@Z$`
M^#M[O-Q_>T(4?.?X.'U(\#A7__`^?.=#>#^=CQQ_R/MX53TH/GSGVA0[G+S<
M?.?J%'^<4A1]"$@X?\KX.(.A`/Q5*?`^?0A3>%3[*#Y_ZDMX?0CB%#^]CQQ]
M"-H4?_Q(.(-A`0`[O;S<?4HX.'_=\A1]2N-X5.?P/C^;CQQ]2O(451XH/GU*
M\A1]/3MX@\$!!#N<O-Q__/H4?[U`.'T\.#A5"/`^?[WC>#^>CQQ\_D-X?[WZ
M%%5;*#Y57_`^.YR\W'_>4#B!00$(?3Q*%'S\0#A_O=H4?][C>#^*CQQ_WDH4
M?0K[>%>I*#X[G+S<?]Y*%'U*Z#A_G#H4@2$!#'T'^#A7O?`^?4<[>#U)RF-\
MY^(45]PH/GSGXA2!(0$0?_SJ>#E*P=9_G/)X?4I"%%?>\#X]"<IC?4KB%%3\
M*#Y]2N(4@2$!%'^\\G@Y",'6?YPZ>'T(^A1]".(45/_P/E5<*#X\Z<IC?0CB
M%($A`1A_W/IX..?!UG^<4GA\Y^H4?.?B%%5=\#Y5'"@^/4G*8WSGXA2!(0$<
M?_SJ>#E*P=9_G$)X?4KR%'U*XA15'O`^5/PH/CT)RF-]2N(4@2$!('^\\G@Y
M",'6?YPZ>'T(^A1]".(45/_P/E5<*#X\Z<IC?0CB%($A`21_W/IX..?!UG^<
M4GA\Y^H4?.?B%%5=\#Y5'"@^/4G*8WSGXA2!(0$H?_SJ>#E*P=9_G$)X?4KR
M%'U*XA15'O`^5/PH/CT)RF-]2N(4@2$!+'^\\G@Y",'6?YPZ>'T(^A1]".(4
M5/_P/E5<*#X\Z<IC?0CB%($A`3!_W/IX..?!UG^<4GA\Y^H4?.?B%%5=\#Y5
M'"@^/4G*8WSGXA2!(0$T?_SJ>#E*P=9_G$)X?4KR%'U*XA15'O`^5/PH/CT)
MRF-]2N(4@2$!.'^\\G@Y",'6?YPZ>'T(^A1]".(45/_P/E5<*#X\Z<IC?0CB
M%($A`3Q_W/IX..?!UG^<4GA\Y^H4?.?B%%5=\#Y5'"@^/4G*8WSGXA2!(0%`
M?_SJ>#E*P=9_G$)X?4KR%'U*XA15'O`^5/PH/CT)RF-]2N(4@2$!1'^\\G@Y
M",'6?YPZ>'T(^A1]".(45/_P/E5<*#X\Z<IC?0CB%($A`4A_W/IX..?!UG^<
M4GA\Y^H4?.?B%%5=\#Y5'"@^/4G*8X$A`4Q\Y^(4.4K!UG_\ZGA_G$)X?4KR
M%%4>\#X]"<IC@2$!4'U*XA14_"@^.0C!UCTIRF-]2N(4.2G!UG^\\GA_G#IX
M?0CZ%'TIZA2#H0%45/_P/GT(XA151R@^?]SZ>'T(.A0_O<IC@.$!6'^<4G@[
MO<'654KP/GTIXA1_W?(451PH/G_]4G@\Y\IC?2GB%'^]0G@XY\'650CP/G_>
MZA15/"@^?5U">'SG8A1_O4IX?Y[B%'SG^A1\Y^H45YXH/GSG\A15*?`^D.,`
M`'T&0A1]15(4?6OB%'TI`A2`X0%<@,0``'SG,GDXP```D4,`$)$#``R18P`$
MD2,`"$""`"2#00%H@V$!;(.!`7"#H0%T@\$!>(/A`7PX(0&`3H``('P(`J:0
M`0&$2``+590A__!\"`*F.&``8)`!`!1(``B!/(!G13R@[\T\P)BZ/.`0,CT`
MP](Y0```8(0C`6"EJXE@QMS^8.=4=F$(X?"0@P``D*,`!)##``B0XP`,D0,`
M$)%#`!210P`8D4,`7(`!`!0X(0`0?`@#IDZ``""4(?_0?`@"IE2I&#A4J!]^
MDT$`&'R:(WB380`<DX$`('R\*WB3X0`L?'\;>)`!`#0[?P`<D\$`*(%#`!2`
M8P!<?2E2%(#_`!A]2D@0+X,``'U*41"1/P`4?.HX4'T(.A21'P`809X`7"$C
M`$!\OBMX?X5(`$&=`.!\>QH4?\7S>']$TWA(``HM@3\`7'T^2A0OB0!`D3\`
M7$&>`.2``0`T@T$`&(-A`!Q\"`.F@X$`((/!`"B#X0`L."$`,$Z``""3H0`D
M+YP`/W^=XWA_7M-X0)T`2'_$\W@XH`!`?V/;>#N]_\!(``G-?^/[>$O_\#4O
MG0`_.]X`0$&=_]P[G/_`5XG1OAU)_\`Y*0`!52DP,G^*XA1_6DH4?T33>']C
MVWA_A>-X2``)C9.?`%R``0`T@Z$`)(-!`!A\"`.F@V$`'(.!`""#P0`H@^$`
M+#@A`#!.@``@?3Y+>'Q[&A1_Q?-X?T33>$@`"4V!/P!<?3Y*%"^)`$"1/P!<
M0)[_)'_C^WB3H0`D?Y[@4']:\A1+_^^52___-)0A_]!\"`*F.4#_@)-A`!P[
M9``<D\$`*'Q^&WB3X0`L?)\C>)`!`#23@0`@DZ$`)(.D`!2#A``85ZGNOCBI
M``%]6TFN+X4`.'Q[*A1`G0%$(*4`0#B```!(``7U?^/[>$O_[RU_8]MX.*``
M.#B```!(``7=5ZG"/E>%1CY7AH0^5X?"/E>H1CY7JH0^FY\`5W_C^WB;OP!;
MF3\`6IB_`%28WP!5F/\`5ID?`%B97P!92__NW8D_``!_X_MXF3X``*$_``"9
M/@`!@3\``%4IPCZ9/@`"@3\``)D^``.)/P`$F3X`!*$_``29/@`%@3\`!%4I
MPCZ9/@`&@3\`!)D^``>)/P`(F3X`"*$_``B9/@`)@3\`"%4IPCZ9/@`*@3\`
M")D^``N)/P`,F3X`#*$_``R9/@`-@3\`#%4IPCZ9/@`.@3\`#)D^``^)/P`0
MF3X`$*$_`!"9/@`1@3\`$%4IPCZ9/@`2@3\`$)D^`!.``0`T@V$`'(.!`"!\
M"`.F@Z$`)(/!`"B#X0`L."$`,$@`!Q`@I0`X.(```$@`!+5+__[8E"'_X'P(
M`J9"GP`%D\$`&'_(`J8_W@`"D`$`)#O>.Q"!7H`$B2H`)"^)``!`G@!LDX$`
M$#D@``&3X0`<@YZ`&(/^@!29*@`D?Y_@0$"<`#"3H0`4.____($_``0[OP`$
M._\`"'TI`Z9.@`0A?Y_@0'^_ZWA!G/_D@Z$`%($^@!POB0``09X`*(!^@`Q(
M``5!@X$`$(/A`!R``0`D@\$`&#@A`"!\"`.F3H``((`!`"2#@0`0@^$`''P(
M`Z:#P0`8."$`($Z``""4(?_@?`@"ID*?``63P0`8?\@"IC_>``*0`0`D.]XZ
M2(">@`2))```+XD``$">`%B!/H`(.4```9.A`!0OB0``D^$`')E$``!!G@`0
M@'Z`##B$``1(``4Q@_Z``(.^@!!_G^A`0)T`&(4___Q]*0.F3H`$(7^?Z$!!
MG?_P@Z$`%(/A`!R``0`D@\$`&#@A`"!\"`.F3H``()0A_\!\"`*FD\$`.#_`
M`8*080`<.]X".)"!`!@X80`<D*$`%#B!`!@XH0`4@3X``)$A`"PY(```D`$`
M1)/A`#Q(``1M/*`!@#Q@`8`XI4K@.&-*D'RD*WA(``+E/2`!@HOI`2@OGP``
M09X!6#T@`8*3H0`T.2G_](.A`!R!*?_\?2D2%#U`/_^!"0``.'T`!&%*__\[
MO0`#?X-00(DH`]9A*0`#F2@#UD&=`:!48Q`Z/^`!@D@`!%F`X0`<@4$`&#T@
M`8(OAP`!@,D!%("J```]``&`/2`!@#D(4&@Y*5!L._\"A'QK&WB0HP``D0,`
M!)##``B1(P`,D'\`!$"=`414Z1`Z.0,`##DI__A5*?"^.2D``7TI`Z:%*@`$
ME2@`!$(`__@XYP`#5.D0.CR``8"`?P`,.4```'^EZW@XA!D<?69;>#C@``!]
M2TDN2``"@2^#``!!G@"X@'\`#$@``T$X@0`H?'T;>#Q@`8`X8TX,3,8Q@DO_
MSLTO@P``09X`?(!_``Q(``2I2``!!8$A`"R!7@``?2E2>3E```!_H^MX0((`
MP(`!`$2#H0`T@\$`.'P(`Z:#X0`\."$`0$Z``"!(``)]/4`!@B^#``"0:@*0
MDZ$`-$&>`)!(``-5/2`!@CDI__2!2?_\?4H2%(%*``";Z@9V2__^A(!_``@O
M@P``09X`&$O_Z?5+__]X@'\`#$@``NU+__]$/&`!@#B!`"@X8TVL3,8Q@DO_
MSADO@P``D'\`"$&>_TQ+_^G!2___1#D@`!!+__[H/(`!@CQ@`8`XA/Z8.&-/
MJ$S&,8)(``"A2``#[3A@``%(``)E/6`!@H%K``!]:0.F3H`$(#U@`8*!:P`$
M?6D#IDZ`!"`]8`&"@6L`"'UI`Z9.@`0@/6`!@H%K``Q]:0.F3H`$(#U@`8*!
M:P`0?6D#IDZ`!"`]8`&"@6L`%'UI`Z9.@`0@/6`!@H%K`!A]:0.F3H`$(#U@
M`8*!:P`<?6D#IDZ`!"`]8`&"@6L`('UI`Z9.@`0@/6`!@H%K`"1]:0.F3H`$
M(#U@`8*!:P`H?6D#IDZ`!"`]8`&"@6L`+'UI`Z9.@`0@/6`!@H%K`#!]:0.F
M3H`$(#U@`8*!:P`T?6D#IDZ`!"`]8`&"@6L`.'UI`Z9.@`0@/6`!@H%K`#Q]
M:0.F3H`$(#U@`8*!:P!`?6D#IDZ`!"`]8`&"@6L`1'UI`Z9.@`0@/6`!@H%K
M`$A]:0.F3H`$(#U@`8*!:P!,?6D#IDZ`!"`]8`&"@6L`4'UI`Z9.@`0@/6`!
M@H%K`%1]:0.F3H`$(#U@`8*!:P!8?6D#IDZ`!"`]8`&"@6L`7'UI`Z9.@`0@
M/6`!@H%K`&!]:0.F3H`$(#U@`8*!:P!D?6D#IDZ`!"`]8`&"@6L`:'UI`Z9.
M@`0@/6`!@H%K`&Q]:0.F3H`$(#U@`8*!:P!P?6D#IDZ`!"`]8`&"@6L`='UI
M`Z9.@`0@/6`!@H%K`'A]:0.F3H`$(#U@`8*!:P!\?6D#IDZ`!"`]8`&"@6L`
M@'UI`Z9.@`0@/6`!@H%K`(1]:0.F3H`$(#U@`8*!:P"(?6D#IDZ`!"`]8`&"
M@6L`C'UI`Z9.@`0@/6`!@H%K`)!]:0.F3H`$(#U@`8*!:P"4?6D#IDZ`!"`]
M8`&"@6L`F'UI`Z9.@`0@/6`!@H%K`)Q]:0.F3H`$(#U@`8*!:P"@?6D#IDZ`
M!"`]8`&"@6L`I'UI`Z9.@`0@/6`!@H%K`*A]:0.F3H`$(#U@`8*!:P"L?6D#
MIDZ`!"`]8`&"@6L`L'UI`Z9.@`0@/6`!@H%K`+1]:0.F3H`$(#U@`8*!:P"X
M?6D#IDZ`!"`]8`&"@6L`O'UI`Z9.@`0@/6`!@H%K`,!]:0.F3H`$(#U@`8*!
M:P#$?6D#IDZ`!"`]8`&"@6L`R'UI`Z9.@`0@/6`!@H%K`,Q]:0.F3H`$(#U@
M`8*!:P#0?6D#IDZ`!"`]8`&"@6L`U'UI`Z9.@`0@/6`!@H%K`-A]:0.F3H`$
M(#U@`8*!:P#<?6D#IDZ`!"`]8`&"@6L`X'UI`Z9.@`0@/6`!@H%K`.1]:0.F
M3H`$(#U@`8*!:P#H?6D#IDZ`!"`]8`&"@6L`['UI`Z9.@`0@/6`!@H%K`/!]
M:0.F3H`$(#U@`8*!:P#T?6D#IDZ`!"`]8`&"@6L`^'UI`Z9.@`0@/6`!@H%K
M`/Q]:0.F3H`$(#U@`8*!:P$`?6D#IDZ`!"!(``$`2```_$@``/A(``#T2```
M\$@``.Q(``#H2```Y$@``.!(``#<2```V$@``-1(``#02```S$@``,A(``#$
M2```P$@``+Q(``"X2```M$@``+!(``"L2```J$@``*1(``"@2```G$@``)A(
M``"42```D$@``(Q(``"(2```A$@``(!(``!\2```>$@``'1(``!P2```;$@`
M`&A(``!D2```8$@``%Q(``!82```5$@``%!(``!,2```2$@``$1(``!`2```
M/$@``#A(```T2```,$@``"Q(```H2```)&````!@````8````&````!@````
M8````&````!@````/8`!@CUK_H"`#/_X.6NT4'P)`Z9\"UH4@8S__'U@6A1.
M@`0@8````&````!@````8````&````!@````8````'P(`J:0`0`$E"'_\$O_
M]MDX(0`0@`$`!'P(`Z9.@``@<'-?<W1R:6YG<R!M:7-S:6YG"@!P97)L>'-I
M+F,````!@%"0`8!-:``````!@$YD`8!.:`&`4(0!@$VP`8!0C``````!@%!P
M`8!0>```````0T%#2$4``"X````N+@``)7,O)7,```!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````4$%27U1%
M35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``%!%4DPU3$E"````
M`%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`
M4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%
M````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!
M4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.````
M`#$```!L<V5E:R!F86EL960`````<F5A9"!F86EL960`3$1?3$E"4D%265]0
M051(`%-94U1%30``)3`R>`````!P87(M`````"5S)7,E<R5S`````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H``%!!5$@`````<&%R;``````N<&%R`````'-H;W)T(')E860``"5S)7-C
M86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``
M```8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP
M-3D```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-10``
M``!414U01$E2`%1-4``O=F%R+W1M<"\```!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%
M1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T
M7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T
M,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A
M<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@
M*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]
M("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@
M3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE
M("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D
M8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM
M>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U
M<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N
M("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-
M;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U
M:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D
M<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T
M;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F
M:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B([
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*
M+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M
M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M
M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R
M9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA
M;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T
M87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO
M8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(
M+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R
M;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A
M<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I
M8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@
M/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?
M34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO
M=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@
M;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H
M(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@
M(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL
M87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N
M9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O
M9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@
M<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T
M7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5
M;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*
M8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L
M:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-
M;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B
M+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A
M;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL
M93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U
M9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF
M;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@
M*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD
M(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA
M<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@
M("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY
M("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E
M("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B
M92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F
M:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N
M86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC
M*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I
M('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`
M05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*
M?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S
M:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@
M<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD[
M"B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=
M.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L
M("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N
M;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z
M.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E
M871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&
M2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E
M<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A
M9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO
M861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L
M92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY
M($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE
M("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP
M?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`
M24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S
M.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J
M96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N
M9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@
M/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I
M;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@
M/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D
M36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT
M96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\
M.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A
M73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B
M*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP
M;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H
M(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F
M*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E
M;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O
M;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@
M=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D[
M"GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N
M?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F
M:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E
M:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?
M;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE
M7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S
M970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D
M;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S
M.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E
M<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@
M/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M
M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@
M>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S
M=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB
M(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50
M871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M
M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ
M4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A
M=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q
M=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG
M<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R
M97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV
M93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER
M92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*
M<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]
M("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N
M86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI
M(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE
M;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52
M?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E
M;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.
M?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY
M("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*
M+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM
M>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM
M("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C
M:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?
M<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B
M=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C
M:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S
M=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0[
M"GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L
M("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I
M"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M
M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE
M9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI
M;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T
M7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N
M9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]
M("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A
M;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD
M<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE
M+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*
M:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@
M+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R
M;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI
M('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O
M.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z
M.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P
M=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%
M*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)5
M1R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)]
M(&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[
M4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@
M;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@
M)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B
M(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E
M>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%
M.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$
M7U\*``$;`SL```$(````(/__A0````$@__^%;````5#__X8(```!D/__AV@`
M``),__^(D````K3__XE8```"Y/__BQ````-\__^+B````Z3__XX,```#_/__
MCK0```0H__^/S```!&#__Y`$```$>/__D!0```20__^2Z```!1S__Y,H```%
M1/__DZ````6$__^5C```!;C__Y88```%X/__EK0```7\__^8F```!D#__YC0
M```&9/__F>@```:@__^@N```!TS__Z,@```'A/__H[0```?P__^R)```""C_
M_[*4```(2/__M"@```BD__^UR````@#__[:0```!T/__MR@```>T__^YE```
M`;P````0``````%Z4@`$?$$!&PP!`````"P````8__^#V````&P`00X@00E!
M`$*>`D6=`Y\!0Q%!?TP&04+?WMT.`````````#P```!(__^$%````)P`00X@
M00E!`$*>`D6<!)\!1!%!?T.=`T_=1`9!0M_>W`X`00X@G`2=`YX"GP$107\`
M```H````B/__A'````%@`$$.($$)00!"G`1"G@)%FP4107]!G0-!GP$`````
M`!````"T__^WT```!5``````````+````,C__[2X````F`!!#B!!"4$`0IX"
M1Q%!?T2=`T*?`4_=0=]#W@X`009!````2````/C__[/`````R`!!#B!!"4$`
M0IX"1Q%!?T*<!$*?`4:=`TK=1MQ!WT/>#@!!!D%!#B"<!)X"GP$107]"W$'?
M009!0MX.`````&0```%$__^%%````2@`0@XP09\!0YL%1)X"2@E!`$&:!D$1
M07]"G`1"G0-/VD';009!0=Q!W4'>0]\.`$$.,)L%G@*?`4B:!IP$G0,107]&
MVMS=!D%!"MM!WD$+0MO>0IL%0ML`````+````:S__X74````R`!!#C!""4$`
MG0-($4%_G@*?`6,*!D%"W][=#@!!"P``````E````=S__X9L```!N`!!#M`!
M09T#0I\!40K?W0X`00M!"4$`09P$01%!?T29!T*:!D*;!4*>`E28"%O80=G:
MV]Y"W$$&04&9!YH&FP6<!)X"$4%_1ME!VD$&04';0=Q!WD&8")D'F@:;!9P$
MG@(107]"V-G:V]S>!D%!"4$`09@(01%!?T&9!T&:!D&;!4&<!$&>`@`````D
M```"=/__AXP```!X`$$.($0)00"?`4,107]4!D%!WPX`````````5````IS_
M_X?<```"A`!!#E!$$4%_FP6<!$.=`YX"2Y\!F0>:!@)$"@9!1M_>W=S;VMD.
M`$$+29@(09<)8PK70=A!"TC7V$*7"9@(1-=!V$.7"4&8"````"@```+T__^*
M"````*@`00[``40)00">`I\!0A%!?U@*!D%!W]X.`$$+````-````R#__XJ$
M```!&`!!#K`(1`E!`)X"0I\!1Q%!?V4*!D%!W]X.`$$+3@H&04'?W@X`00L`
M```4```#6/__BV0````X`$(.$$L.```````4```#</__BX0````0`$$.$$(.
M``````"(```#B/__BWP```+4`$$.\`E$"4$`F@9$G`2?`4H107^9!P5&#%4*
M"48,0@9!0@9&0]_<VMD.`$$+09L%294+0I8*0I<)0I@(0YX"09T#`D,*U4'6
M0==!V$';0=U!WD$+5M5!UD'70=A!VT'=0=Y!FP5!VT*5"T&6"D&7"4&8"$&;
M!4&=`T&>`@```"0```04__^-Q````$``00X@0PE!`)\!0A%!?TC?#@!!!D$`
M```````\```$//__C=P```!X`$$.($&?`48)00!!$4%_2-\.`$$&04$.()\!
M1-\.`$$.()\!$4%_1-\.`$$&00``````,```!'S__XX4```![`!!#D!%$4%_
MFP5$G`2=`T*>`D*?`0)<"@9!1-_>W=S;#@!!"P```"0```2P__^/S````(P`
M00XP0PE!`)\!0A%!?UH*WPX`009!00L````8```$V/__D#````"<`$$.@`%"
M$4%_````````0```!/3__Y"P```!Y`!%#M"`!$4)00"8")H&39L%G@(107^7
M"9D'G`2=`Y\!`D4*!D%(W][=W-O:V=C7#@!!"P`````@```%./__DE`````X
M`$$.$$(107]'"@X`009!00L````````X```%7/__DF0```$8`$$.0$()00">
M`D:<!)T#GP%($4%_39L%5=M-"@9!0]_>W=P.`$$+09L%``````"H```%F/__
MDT````;0`$$.T`)""4$`G@)$G`10FP5,F@9)$4%_GP%(G0-!EPE!F`A!F0<"
M6M="V$'90=U*!D%$W][<V]H.`$$.T`*7"9@(F0>:!IL%G`2=`YX"GP$107]V
MU]C9W467"9@(F0>=`UN5"T*6"D/50=9(E0N6"@);"M5!UD'70=A!V4'=00L"
M0-76U]C9W4&5"T&6"D&7"4&8"$&9!T&=`P``````-```!D3__YED```":`!!
M#D!#"4$`GP%(G0,107^;!9P$0IX"`F4*!D%$W][=W-L.`$$+```````L```&
M?/__FY0```"4`$$.($0107^>`I\!5PH&04'?W@X`00M%!D%!W]X.```````X
M```&K/__KVP```)L`$$.0$()00">`DT107^?`4V=`P).W4(&04+?W@X`00Y`
MG@*?`1%!?T6=`P`````T```&Z/__F[P```YP`$$.@`-0F@:;!9P$G0.>`I\!
M`P.'"M_>W=S;V@X`00M!"4$`01%!?P```!P```<@__^I]````'``00X00Q%!
M?U8.`$$&00``````6```!T#__ZI$```!E`!!#C!$"4$`F@9#FP6<!$*?`4\1
M07^>`E(*!D%$W][<V]H.`$$+09T#7-U"!D%%W][<V]H.`$$.,)H&FP6<!)X"
MGP$107],G0,````````T```'G/__JWP```&@`$$.,$,)00";!4*>`D*?`401
M07^<!)T#`E,*!D%$W][=W-L.`$$+````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#_____
M`````/____\``````````````````````````````````````8(!$`&!_H0!
M@?Z$`8`/I`&`#Z0!@?Z$`8'^A`&`31`!@@$8`8(!(`&"`1`!@@)8`8'_$`&!
M_H0!@!,,`8'^A`&`3/`!@?Z(`8("7``````!@(_<`8'^B`&!_I`!@?Z0````
M``````$````!`````0```E4````!```"7P````$```*;`````0```L$````/
M```$2@````P!@!+(````#0&`3/`````$`8`!>`````4!@`K4````!@&`!)0`
M```*```$D@````L````0````%0`````````#`8(```````(```,,````%```
M``<````7`8`/O'`````!@?_T````!P&`#V@````(```#8`````D````,````
M````````````````````````````````````````````````````````````
M``````&!_Q````````````&`2[`!@$NT`8!+N`&`2[P!@$O``8!+Q`&`2\@!
M@$O,`8!+T`&`2]0!@$O8`8!+W`&`2^`!@$OD`8!+Z`&`2^P!@$OP`8!+]`&`
M2_@!@$O\`8!,``&`3`0!@$P(`8!,#`&`3!`!@$P4`8!,&`&`3!P!@$P@`8!,
M)`&`3"@!@$PL`8!,,`&`3#0!@$PX`8!,/`&`3$`!@$Q$`8!,2`&`3$P!@$Q0
M`8!,5`&`3%@!@$Q<`8!,8`&`3&0!@$QH`8!,;`&`3'`!@$QT`8!,>`&`3'P!
M@$R``8!,A`&`3(@!@$R,`8!,D`&`3)0!@$R8`8!,G`&`3*`!@$RD`8!,J`&`
M3*P!@$RP"E!!4BYP;0H``````8("6`&`4)Q'0T,Z("A.971"4T0@;F(S(#(P
M,3DP,S$Y*2`W+C0N,`!'0T,Z("AN8C,@,C`Q.3`S,3DI(#<N-"XP`"1.971"
M4T0Z(&-R=#`N4RQV(#$N-R`R,#$X+S$Q+S(V(#$W.C,W.C0U(&IO97)G($5X
M<"`D`"1.971"4T0Z(&-R=#`M8V]M;6]N+F,L=B`Q+C(S(#(P,3@O,3(O,C@@
M,C`Z,3(Z,S4@8VAR:7-T;W,@17AP("0`)$YE=$)31#H@8W)T:2Y3+'8@,2XT
M(#(P,30O,#,O,#8@,3DZ,#4Z-3D@;6%T="!%>'`@)``D3F5T0E-$.B!C<G1B
M96=I;BYC+'8@,2XQ-R`R,#$X+S$R+S(X(#$X.C$W.C$Q(&-H<FES=&]S($5X
M<"`D`"1.971"4T0Z(&-R=&5N9"Y3+'8@,2XS(#(P,30O,#(O,C<@,38Z-#<Z
M-#@@;6%T="!%>'`@)``D3F5T0E-$.B!C<G1N+E,L=B`Q+C(@,C`Q-"\P,B\R
M-R`Q-CHT-SHT."!M871T($5X<"`D`$$````/9VYU``$````'!`$`+G-H<W1R
M=&%B`"YI;G1E<G``+FYO=&4N;F5T8G-D+FED96YT`"YN;W1E+FYE=&)S9"YP
M87@`+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F
M<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1A=&$N<F5L+G)O`"YF:7AU<``N
M9V]T,@`N9'EN86UI8P`N9V]T`"YD871A`"YS9&%T80`N<V)S<P`N8G-S`"YC
M;VUM96YT`"YG;G4N871T<FEB=71E<P``````````````````````````````
M````````````````````````````"P````$````"`8`!-````30````7````
M```````````!`````````!,````'`````@&``4P```%,````&```````````
M````!``````````F````!P````(!@`%D```!9````!0```````````````0`
M````````-P````4````"`8`!>````7@```,<````!0`````````$````!```
M`#T````+`````@&`!)0```24```&0`````8````!````!````!````!%````
M`P````(!@`K4```*U```!)(```````````````$`````````30````0````"
M`8`/:```#V@```!4````!0`````````$````#````%<````$````0@&`#[P`
M``^\```##`````4````7````!`````P```!A`````0````8!@!+(```2R```
M`"````````````````0`````````9P````$````&`8`2\```$O```#H`````
M```````````0`````````&T````!````!@&`3/```$SP````(```````````
M````!`````````!S`````0````(!@$T0``!-$```0/P```````````````0`
M````````>P````$````"`8".#```C@P```$,```````````````$````````
M`(D````!`````@&`CQ@``(\8```'U```````````````!`````````"3````
M`0````,!@?Z$``#^A`````@```````````````0`````````F@````$````#
M`8'^C```_HP````(```````````````$`````````*$````!`````P&!_I0`
M`/Z4````!```````````````!`````````"F`````0````,!@?Z8``#^F```
M`!,```````````````@`````````LP````$````#`8'^K```_JP````$````
M```````````$`````````+H````!`````P&!_K```/ZP````8```````````
M````!`````````#`````!@````,!@?\0``#_$````.`````&``````````0`
M```(````R0````$````#`8'_\```__`````0```````````````$````!```
M`%P````!`````P&"`````0`````!!```````````````!`````````#.````
M`0````,!@@$$``$!!`````D```````````````0`````````U`````$````#
M`8(!$``!`1`````(```````````````$`````````-L````(`````P&"`1@`
M`0$8````$```````````````"`````````#A````"`````,!@@$H``$!&```
M`6P```````````````@`````````Y@````$````P```````!`1@````[````
M```````````!`````0```!\````!`````````````0%3```!5@``````````
M`````0````````#O;___]0````````````$"J0```!````````````````$`
K`````````0````,````````````!`KD```#_```````````````!````````
